Welcome to pyson’s documentation! — pyson v0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- pyson v0.1.2 documentation »

# Welcome to pyson’s documentation!

Contents:

- Basic JSON structures
  - JSON Paths
  - Setting values
- Data Types
  - JSON Type Level
  - Internal description of data types

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- modules |
- next |
- pyson v0.1.2 documentation »